==> archimedes-1.2.0.tar.gz: archimedes-1.2.0/src/AlAs.h <==
/* AlAs.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 26 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// conduction band calculated using the model : sp3s* (see Vogl)
// data interpolated by a 10-th order polynomial

CB_FULL[ALAS][0]=-9.2163e+06;
CB_FULL[ALAS][1]=-2.3110e+12;
CB_FULL[ALAS][2]=-2.1654e+10;
CB_FULL[ALAS][3]=-1.2697e+12;
CB_FULL[ALAS][4]=-3.2665e+13;
CB_FULL[ALAS][5]=1.2357e+12;
CB_FULL[ALAS][6]=-1.8531e+10;
CB_FULL[ALAS][7]=1.3567e+08;
CB_FULL[ALAS][8]=-4.2892e+05;
CB_FULL[ALAS][9]=7.2273e+01;
CB_FULL[ALAS][10]=3.0310e+00;

==> archimedes-2.0.0.tar.gz: archimedes-2.0.0/src/AlAs.h <==
/* AlAs.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 31 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// Parabolic conduction band
// Gamma valley 100-direction

CB_FULL[ALAS][0]=+2.4979e+22;
CB_FULL[ALAS][1]=-1.2874e+21;
CB_FULL[ALAS][2]=+2.8114e+19;
CB_FULL[ALAS][3]=-3.3899e+17;
CB_FULL[ALAS][4]=+2.4652e+15;
CB_FULL[ALAS][5]=-1.1087e+13;
CB_FULL[ALAS][6]=+3.0401e+10;
CB_FULL[ALAS][7]=-4.8238e+07;
CB_FULL[ALAS][8]=+1.0135e+07;
CB_FULL[ALAS][9]=-1.3957e+01;
CB_FULL[ALAS][10]=0.0; //1.2785e-03;
